@@ -4,7 +4,7 @@ from __future__ import annotations
 
 import argparse
 import sys
-from typing import TYPE_CHECKING, Callable, Iterable, Iterator
+from typing import TYPE_CHECKING, Callable, ClassVar, Iterable, Iterator
 
 # rich is only used to display help. It is imported inside the functions in order
 # not to add delays to command line tools that use this formatter.
@@ -28,8 +28,8 @@ _Groups = Iterable[argparse._ArgumentGroup]
 class RichHelpFormatter(argparse.HelpFormatter):
     """An argparse HelpFormatter class that renders using rich."""
 
-    group_name_formatter: Callable[[str], str] = str.upper
-    styles: dict[str, StyleType] = {
+    group_name_formatter: ClassVar[Callable[[str], str]] = str.upper
+    styles: ClassVar[dict[str, StyleType]] = {
         "argparse.args": "cyan",
         "argparse.groups": "dark_orange",
         "argparse.help": "default",
@@ -37,11 +37,11 @@ class RichHelpFormatter(argparse.HelpFormatter):
         "argparse.syntax": "bold",
         "argparse.text": "default",
     }
-    highlights: list[str] = [
+    highlights: ClassVar[list[str]] = [
         r"(?:^|\s)(?P<args>-{1,2}[\w]+[\w-]*)",  # highlight --words-with-dashes as args
         r"`(?P<syntax>[^`]*)`",  # highlight text in backquotes as syntax
     ]
-    usage_markup: bool = False
+    usage_markup: ClassVar[bool] = False
 
     def __init__(
         self,
@@ -60,7 +60,7 @@ class RichHelpFormatter(argparse.HelpFormatter):
         def __init__(
             self,
             formatter: RichHelpFormatter,
-            parent: RichHelpFormatter._Section,
+            parent: RichHelpFormatter._Section | None,
             heading: str | None = None,
         ) -> None:
             if heading is not None:
@@ -315,7 +315,7 @@ if __name__ == "__main__":
     parser.add_argument(
         "formatter-class",
         help=(
-            "All you need to make you argparse ArgumentParser output colorful text like this is to "
+            "All you need to make your argparse.ArgumentParser output colorful text like this is to "
             "pass it `formatter_class=RichHelpFormatter` or any of the available variants."
         ),
     )
@@ -324,7 +324,7 @@ if __name__ == "__main__":
         nargs="*",
         help=(
             "All the styles used by this formatter are defined in the `RichHelpFormatter.styles` "
-            "dictionary and customizable. Any rich style can be used."
+            "dictionary and they can be changed. Any rich style can be used."
         ),
     )
     parser.add_argument(
@@ -339,7 +339,10 @@ if __name__ == "__main__":
     parser.add_argument(
         "--syntax",
         default=RichHelpFormatter.styles["argparse.syntax"],
-        help="Text inside backtics is highlighted using the `argparse.syntax` style (default: '%(default)s')",
+        help=(
+            "Text inside backticks is highlighted using the `argparse.syntax` style "
+            "(default: '%(default)s')"
+        ),
     )
     parser.add_argument(
         "-s",
@@ -363,11 +366,7 @@ if __name__ == "__main__":
     group.add_argument(
         "--others",
         nargs="*",
-        help=(
-            "This formatter works with subparsers, mutually exclusive groups and hidden arguments. "
-            "It also works with other help formatters such as `ArgumentDefaultsHelpFormatter` and "
-            "`MetavarTypeHelpFormatter`."
-        ),
+        help="This formatter works with subparsers, mutually exclusive groups and hidden arguments.",
     )
     mutex = group.add_mutually_exclusive_group()
     mutex.add_argument(
